#!/usr/bin/env python
# -*- coding:utf-8 -*-

# file:setup.py.py
# author:PigKnight
# datetime:2022/3/6 16:55
# software: PyCharm
"""
this is function description
"""
# import module your need
import setuptools

setuptools.setup()
